@@ -51,7 +51,7 @@ class CTestPrecisionWithoutDamping(ITest):
             if not cluster():
                 call_spin()
             else:
-                call_sbatch('home/../../work_beegfs/supas384/jobs/job_cau_agheinze.sh')
+                call_sbatch('~/../../work_beegfs/supas384/jobs/job_cau_agheinze.sh')
         while not (self.tempdir / 'SpinSTM_end.dat').is_file():
             time.sleep(0.2)
 
